==============================================
django-user-accounts: user accounts for Django
==============================================

Provides user accounts to a GeoNode project.

Forked from django-user-account for implementing the user invitation feature.
When in django-user-account it will be re-enabled that feature (once existing in 
Pinax) we will move back to it.

Requirements
============

* Django 1.4+
* Python 2.6+ or Python 3.3+
* django-appconf (included in ``install_requires``)
* pytz (included in ``install_requires``)

Documentation
=============

See http://django-user-accounts.readthedocs.org/
